@@ -1,6 +1,5 @@
-use crate::error::Error;
+use crate::error::{Error, Result};
 
-use anyhow::Result;
 use bytes::BufMut;
 
 // returns the padding required to make the length a multiple of 4
@@ -31,7 +30,7 @@ pub(crate) fn set_nbits_of_uint16(
     mut val: u16,
 ) -> Result<u16> {
     if start_index + size > 16 {
-        return Err(Error::InvalidSizeOrStartIndex.into());
+        return Err(Error::InvalidSizeOrStartIndex);
     }
 
     // truncate val to size bits
@@ -106,7 +105,7 @@ mod test {
 
         for (name, source, size, index, value, result, err) in tests {
             let res = set_nbits_of_uint16(source, size, index, value);
-            if let Some(_) = err {
+            if err.is_some() {
                 assert!(res.is_err(), "setNBitsOfUint16 {} : should be error", name);
             } else if let Ok(got) = res {
                 assert_eq!(got, result, "setNBitsOfUint16 {}", name);
